@@ -59,7 +59,8 @@ Erlang <- R6Class("Erlang",
     #' The arithmetic mean of a (discrete) probability distribution X is the expectation
     #' \deqn{E_X(X) = \sum p_X(x)*x}
     #' with an integration analogue for continuous distributions.
-    mean = function() {
+    #' @param ... Unused.
+    mean = function(...) {
       unlist(self$getParameterValue("shape")) / unlist(self$getParameterValue("rate"))
     },
 
@@ -76,7 +77,8 @@ Erlang <- R6Class("Erlang",
     #' \deqn{var_X = E[X^2] - E[X]^2}
     #' where \eqn{E_X} is the expectation of distribution X. If the distribution is multivariate the
     #' covariance matrix is returned.
-    variance = function() {
+    #' @param ... Unused.
+    variance = function(...) {
       unlist(self$getParameterValue("shape")) / (unlist(self$getParameterValue("rate"))^2)
     },
 
@@ -85,7 +87,8 @@ Erlang <- R6Class("Erlang",
     #' \deqn{sk_X = E_X[\frac{x - \mu}{\sigma}^3]}{sk_X = E_X[((x - \mu)/\sigma)^3]}
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
-    skewness = function() {
+    #' @param ... Unused.
+    skewness = function(...) {
       2 / sqrt(unlist(self$getParameterValue("shape")))
     },
 
@@ -95,7 +98,8 @@ Erlang <- R6Class("Erlang",
     #' where \eqn{E_X} is the expectation of distribution X, \eqn{\mu} is the mean of the
     #' distribution and \eqn{\sigma} is the standard deviation of the distribution.
     #' Excess Kurtosis is Kurtosis - 3.
-    kurtosis = function(excess = TRUE) {
+    #' @param ... Unused.
+    kurtosis = function(excess = TRUE, ...) {
       if (excess) {
         return(6 / unlist(self$getParameterValue("shape")))
       } else {
@@ -108,7 +112,8 @@ Erlang <- R6Class("Erlang",
     #' \deqn{- \sum (f_X)log(f_X)}
     #' where \eqn{f_X} is the pdf of distribution X, with an integration analogue for
     #' continuous distributions.
-    entropy = function(base = 2) {
+    #' @param ... Unused.
+    entropy = function(base = 2, ...) {
       shape <- unlist(self$getParameterValue("shape"))
       rate <- unlist(self$getParameterValue("rate"))
 
@@ -118,7 +123,8 @@ Erlang <- R6Class("Erlang",
     #' @description The moment generating function is defined by
     #' \deqn{mgf_X(t) = E_X[exp(xt)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    mgf = function(t) {
+    #' @param ... Unused.
+    mgf = function(t, ...) {
       if (t < self$getParameterValue("rate")) {
         return((1 - self$getParameterValue("scale") * t)^(-self$getParameterValue("shape"))) # nolint
       } else {
@@ -129,14 +135,16 @@ Erlang <- R6Class("Erlang",
     #' @description The characteristic function is defined by
     #' \deqn{cf_X(t) = E_X[exp(xti)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    cf = function(t) {
+    #' @param ... Unused.
+    cf = function(t, ...) {
       (1 - self$getParameterValue("scale") * 1i * t)^(-self$getParameterValue("shape")) # nolint
     },
 
     #' @description The probability generating function is defined by
     #' \deqn{pgf_X(z) = E_X[exp(z^x)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    pgf = function(z) {
+    #' @param ... Unused.
+    pgf = function(z, ...) {
       return(NaN)
     },
 
