@@ -75,7 +75,8 @@ ShiftedLoglogistic <- R6Class("ShiftedLoglogistic",
     #' The arithmetic mean of a (discrete) probability distribution X is the expectation
     #' \deqn{E_X(X) = \sum p_X(x)*x}
     #' with an integration analogue for continuous distributions.
-    mean = function() {
+    #' @param ... Unused.
+    mean = function(...) {
       location <- unlist(self$getParameterValue("location"))
       scale <- unlist(self$getParameterValue("scale"))
       shape <- unlist(self$getParameterValue("shape"))
@@ -108,7 +109,8 @@ ShiftedLoglogistic <- R6Class("ShiftedLoglogistic",
     #' \deqn{var_X = E[X^2] - E[X]^2}
     #' where \eqn{E_X} is the expectation of distribution X. If the distribution is multivariate the
     #' covariance matrix is returned.
-    variance = function() {
+    #' @param ... Unused.
+    variance = function(...) {
       scale <- unlist(self$getParameterValue("scale"))
       shape <- unlist(self$getParameterValue("shape"))
       shapi <- pi * unlist(self$getParameterValue("shape"))
@@ -119,7 +121,8 @@ ShiftedLoglogistic <- R6Class("ShiftedLoglogistic",
     #' @description The probability generating function is defined by
     #' \deqn{pgf_X(z) = E_X[exp(z^x)]}
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
-    pgf = function(z) {
+    #' @param ... Unused.
+    pgf = function(z, ...) {
       return(NaN)
     },
 
